@@ -9,15 +9,12 @@ pub type CargoManifest = cargo_toml::Manifest<Metadata>;
 pub struct Metadata {
     pub app_name: Option<String>,
     pub version_name: Option<String>,
-    pub version_code: Option<String>,
+    pub version_code: Option<u32>,
     pub min_sdk_version: Option<u32>,
     pub target_sdk_version: Option<u32>,
     pub max_sdk_version: Option<u32>,
     pub icon: Option<String>,
 
-    #[serde(default)]
-    pub android_permissions: Vec<UsesPermission>,
-
     #[serde(default)]
     pub use_android_manifest: bool,
     pub android_manifest_path: Option<PathBuf>,
@@ -26,7 +23,8 @@ pub struct Metadata {
     pub use_info_plist: bool,
     pub info_plist_path: Option<PathBuf>,
 
-    pub android_app_id: Option<String>,
+    /// Android package name to place in AndroidManifest.xml.
+    pub android_package_name: Option<String>,
     /// Android resources directory path relatively to project path.
     pub android_res: Option<PathBuf>,
     /// Android assets directory path relatively to project path.
@@ -40,4 +38,8 @@ pub struct Metadata {
     pub apple_res: Option<PathBuf>,
     /// Apple assets directory path relatively to project path.
     pub apple_assets: Option<PathBuf>,
+
+    /// TODO: Add android android_uses_features.
+    #[serde(default)]
+    pub android_permissions: Vec<UsesPermission>,
 }
